@@ -69,7 +69,7 @@ def get_dict_of_struct(struct, connection=None, fetch_nested=False, attributes=N
             value = None
         nested_obj = dict(
             (attr, convert_value(getattr(value, attr)))
-            for attr in attributes if getattr(value, attr, None)
+            for attr in attributes if getattr(value, attr, None) is not None
         )
         nested_obj['id'] = getattr(value, 'id', None)
         nested_obj['href'] = getattr(value, 'href', None)
@@ -102,7 +102,7 @@ def get_dict_of_struct(struct, connection=None, fetch_nested=False, attributes=N
             ret = []
             for i in value:
                 if isinstance(i, sdk.Struct):
-                    if fetch_nested and i.href:
+                    if not nested and fetch_nested and i.href:
                         ret.append(resolve_href(i))
                     elif not nested:
                         ret.append(get_dict_of_struct(i))
