@@ -17,7 +17,7 @@ DOCUMENTATION = '''
 ---
 module: azure_rm_sqldatabase
 version_added: "2.5"
-short_description: Manage SQL Database instance.
+short_description: Manage SQL Database instance
 description:
     - Create, update and delete instance of SQL Database.
 
@@ -36,22 +36,21 @@ options:
         required: True
     location:
         description:
-            - Resource location. If not set, location from the resource group will be used as C(default).
+            - Resource location. If not set, location from the resource group will be used as default.
     collation:
         description:
-            - The collation of the database. If I(create_mode) is not C(default), this value is ignored.
+            - The collation of the database. If not I(create_mode=default), this value is ignored.
     create_mode:
         description:
             - Specifies the mode of database creation.
-            - "C(default): regular database creation."
-            - "C(copy): creates a database as a copy of an existing database."
-            - "C(online_secondary)/C(non_readable_secondary): creates a database as a (readable or nonreadable) secondary replica of an existing database."
-            - "C(point_in_time_restore): Creates a database by restoring a point in time backup of an existing database."
-            - "C(recovery): Creates a database by restoring a geo-replicated backup."
-            - "C(restore): Creates a database by restoring a backup of a deleted database."
-            - "C(restore_long_term_retention_backup): Creates a database by restoring from a long term retention vault."
-            - "C(copy), C(non_readable_secondary), C(online_secondary) and C(restore_long_term_retention_backup) are not supported for C(data_warehouse)
-               edition."
+            - C(default), regular database creation.
+            - C(copy), creates a database as a copy of an existing database.
+            - C(online_secondary)/C(non_readable_secondary), creates a database as a (readable or nonreadable) secondary replica of an existing database.
+            - C(point_in_time_restore), Creates a database by restoring a point in time backup of an existing database.
+            - C(recovery), Creates a database by restoring a geo-replicated backup.
+            - C(restore), Creates a database by restoring a backup of a deleted database.
+            - C(restore_long_term_retention_backup), Creates a database by restoring from a long term retention vault.
+            - C(copy), C(non_readable_secondary), C(online_secondary) and C(restore_long_term_retention_backup) are not supported for C(data_warehouse) edition.
         choices:
             - 'copy'
             - 'default'
@@ -63,27 +62,27 @@ options:
             - 'restore_long_term_retention_backup'
     source_database_id:
         description:
-            - Required unless I(create_mode) is C(default) or C(restore_long_term_retention_backup).
-            - Specifies the resource ID of the source database
+            - Required unless I(create_mode=default) or I(create_mode=restore_long_term_retention_backup).
+            - Specifies the resource ID of the source database.
     source_database_deletion_date:
         description:
-            - "Required if I(create_mode) is C(restore) and I(source_database_id) is the deleted database's original resource id when it existed (as
-               opposed to its current restorable dropped database id), then this value is required. Specifies the time that the database was deleted."
+            - Required if I(create_mode=restore) and I(source_database_id) is the deleted database's original resource id when it existed (as
+               opposed to its current restorable dropped database ID), then this value is required. Specifies the time that the database was deleted.
     restore_point_in_time:
         description:
-            - "Required if I(create_mode) is C(point_in_time_restore), this value is required. If I(create_mode) is C(restore), this value is optional.
-               Specifies the point in time (ISO8601 format) of the source database that will be restored to create the new database. Must be greater than
-               or equal to the source database's earliestRestoreDate value."
+            - Required if I(create_mode=point_in_time_restore), this value is required. If I(create_mode=restore), this value is optional.
+            - Specifies the point in time (ISO8601 format) of the source database that will be restored to create the new database.
+            - Must be greater than or equal to the source database's earliestRestoreDate value.
     recovery_services_recovery_point_resource_id:
         description:
-            - "Required if I(create_mode) is C(restore_long_term_retention_backup), then this value is required. Specifies the resource ID of the
-               recovery point to restore from."
+            - Required if I(create_mode=restore_long_term_retention_backup), then this value is required.
+            - Specifies the resource ID of the recovery point to restore from.
     edition:
         description:
-            - "The edition of the database. The DatabaseEditions enumeration contains all the valid editions. If I(create_mode) is C(non_readable_secondary)
-              or C(online_secondary), this value is ignored. To see possible values, query the capabilities API
-               (/subscriptions/{subscriptionId}/providers/Microsoft.Sql/locations/{locationID}/capabilities) referred to by operationId:
-               'Capabilities_ListByLocation.'."
+            - The edition of the database. The DatabaseEditions enumeration contains all the valid editions.
+            - If I(create_mode=non_readable_secondary) or I(create_mode=online_secondary), this value is ignored.
+            - To see possible values, query the capabilities API (/subscriptions/{subscriptionId}/providers/Microsoft.Sql/locations/{locationID}/capabilities)
+              referred to by operationId:'Capabilities_ListByLocation'.
         choices:
             - 'web'
             - 'business'
@@ -97,22 +96,24 @@ options:
             - 'system2'
     max_size_bytes:
         description:
-            - "The max size of the database expressed in bytes. If I(create_mode) is not C(default), this value is ignored. To see possible values, query the
-               capabilities API (/subscriptions/{subscriptionId}/providers/Microsoft.Sql/locations/{locationID}/capabilities) referred to by operationId:
-               'Capabilities_ListByLocation.'"
+            - The max size of the database expressed in bytes.
+            - If not I(create_mode=default), this value is ignored.
+            - To see possible values, query the capabilities API (/subscriptions/{subscriptionId}/providers/Microsoft.Sql/locations/{locationID}/capabilities).
+              referred to by operationId:'Capabilities_ListByLocation'.
     elastic_pool_name:
         description:
-            - "The name of the elastic pool the database is in. Not supported for C(data_warehouse) edition."
+            - The name of the elastic pool the database is in. Not supported for I(edition=data_warehouse).
     read_scale:
         description:
-            - "If the database is a geo-secondary, indicates whether read-only connections are allowed to this database or not. Not supported for
-               C(data_warehouse) edition."
+            - If the database is a geo-secondary, indicates whether read-only connections are allowed to this database or not.
+            - Not supported for I(edition=data_warehouse).
         type: bool
         default: False
     sample_name:
         description:
-            - "Indicates the name of the sample schema to apply when creating this database. If I(create_mode) is not C(default), this value is ignored. Not
-               supported for C(data_warehouse) edition."
+            - Indicates the name of the sample schema to apply when creating this database.
+            - If not I(create_mode=default), this value is ignored.
+            - Not supported for I(edition=data_warehouse).
         choices:
             - 'adventure_works_lt'
     zone_redundant:
@@ -127,7 +128,7 @@ options:
       type: bool
     state:
       description:
-        - Assert the state of the SQL Database. Use 'present' to create or update an SQL Database and 'absent' to delete it.
+        - Assert the state of the SQL Database. Use C(present) to create or update an SQL Database and C(absent) to delete it.
       default: present
       choices:
         - absent
@@ -135,39 +136,40 @@ options:
 
 extends_documentation_fragment:
     - azure
+    - azure_tags
 
 author:
-    - "Zim Kalinowski (@zikalino)"
+    - Zim Kalinowski (@zikalino)
 
 '''
 
 EXAMPLES = '''
   - name: Create (or update) SQL Database
     azure_rm_sqldatabase:
-      resource_group: sqlcrudtest-4799
+      resource_group: myResourceGroup
       server_name: sqlcrudtest-5961
       name: testdb
       location: eastus
 
   - name: Restore SQL Database
     azure_rm_sqldatabase:
-      resource_group: sqlcrudtest-4799
+      resource_group: myResourceGroup
       server_name: sqlcrudtest-5961
       name: restoreddb
       location: eastus
       create_mode: restore
-      restorable_dropped_database_id: "/subscriptions/00000000-1111-2222-3333-444444444444/resourceGroups/Default-SQL-SouthEastAsia/providers/Microsoft.Sql/s
-                                      ervers/testsvr/restorableDroppedDatabases/testdb2,131444841315030000"
+      restorable_dropped_database_id: "/subscriptions/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/resourceGroups/myResourceGroup/providers/Microsoft.Sql/s
+                                       ervers/testsvr/restorableDroppedDatabases/testdb2,131444841315030000"
 
   - name: Create SQL Database in Copy Mode
     azure_rm_sqldatabase:
-      resource_group: sqlcrudtest-4799
+      resource_group: myResourceGroup
       server_name: sqlcrudtest-5961
       name: copydb
       location: eastus
       create_mode: copy
-      source_database_id: "/subscriptions/00000000-1111-2222-3333-444444444444/resourceGroups/Default-SQL-SouthEastAsia/providers/Microsoft.Sql/servers/tests
-                          vr/databases/testdb"
+      source_database_id: "/subscriptions/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/resourceGroups/myResourceGroup/providers/Microsoft.Sql/servers/tests
+                           vr/databases/testdb"
 
 '''
 
@@ -177,7 +179,7 @@ id:
         - Resource ID.
     returned: always
     type: str
-    sample: "/subscriptions/00000000-1111-2222-3333-444444444444/resourceGroups/sqlcrudtest-4799/providers/Microsoft.Sql/servers/sqlcrudtest-5961/databases/t
+    sample: "/subscriptions/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx/resourceGroups/myResourceGroup/providers/Microsoft.Sql/servers/sqlcrudtest-5961/databases/t
             estdb"
 database_id:
     description:
@@ -194,11 +196,11 @@ status:
 '''
 
 import time
-from ansible.module_utils.azure_rm_common import AzureRMModuleBase
+from ansible.module_utils.azure_rm_common import AzureRMModuleBase, format_resource_id
 
 try:
     from msrestazure.azure_exceptions import CloudError
-    from msrestazure.azure_operation import AzureOperationPoller
+    from msrest.polling import LROPoller
     from azure.mgmt.sql import SqlManagementClient
     from msrest.serialization import Model
 except ImportError:
@@ -210,7 +212,7 @@ class Actions:
     NoAction, Create, Update, Delete = range(4)
 
 
-class AzureRMDatabases(AzureRMModuleBase):
+class AzureRMSqlDatabase(AzureRMModuleBase):
     """Configuration class for an Azure RM SQL Database resource"""
 
     def __init__(self):
@@ -301,19 +303,20 @@ class AzureRMDatabases(AzureRMModuleBase):
         self.server_name = None
         self.name = None
         self.parameters = dict()
+        self.tags = None
 
         self.results = dict(changed=False)
         self.state = None
         self.to_do = Actions.NoAction
 
-        super(AzureRMDatabases, self).__init__(derived_arg_spec=self.module_arg_spec,
-                                               supports_check_mode=True,
-                                               supports_tags=False)
+        super(AzureRMSqlDatabase, self).__init__(derived_arg_spec=self.module_arg_spec,
+                                                 supports_check_mode=True,
+                                                 supports_tags=True)
 
     def exec_module(self, **kwargs):
         """Main module execution method"""
 
-        for key in list(self.module_arg_spec.keys()):
+        for key in list(self.module_arg_spec.keys()) + ['tags']:
             if hasattr(self, key):
                 setattr(self, key, kwargs[key])
             elif kwargs[key] is not None:
@@ -336,7 +339,7 @@ class AzureRMDatabases(AzureRMModuleBase):
                 elif key == "max_size_bytes":
                     self.parameters["max_size_bytes"] = kwargs[key]
                 elif key == "elastic_pool_name":
-                    self.parameters["elastic_pool_name"] = kwargs[key]
+                    self.parameters["elastic_pool_id"] = kwargs[key]
                 elif key == "read_scale":
                     self.parameters["read_scale"] = 'Enabled' if kwargs[key] else 'Disabled'
                 elif key == "sample_name":
@@ -345,7 +348,7 @@ class AzureRMDatabases(AzureRMModuleBase):
                         ev = 'AdventureWorksLT'
                     self.parameters["sample_name"] = ev
                 elif key == "zone_redundant":
-                    self.parameters["zone_redundant"] = 'Enabled' if kwargs[key] else 'Disabled'
+                    self.parameters["zone_redundant"] = True if kwargs[key] else False
 
         old_response = None
         response = None
@@ -355,6 +358,9 @@ class AzureRMDatabases(AzureRMModuleBase):
         if "location" not in self.parameters:
             self.parameters["location"] = resource_group.location
 
+        if "elastic_pool_id" in self.parameters:
+            self.format_elastic_pool_id()
+
         old_response = self.get_sqldatabase()
 
         if not old_response:
@@ -380,6 +386,9 @@ class AzureRMDatabases(AzureRMModuleBase):
                 if (('edition' in self.parameters) and
                         (self.parameters['edition'] != old_response['edition'])):
                     self.to_do = Actions.Update
+                update_tags, newtags = self.update_tags(old_response.get('tags', dict()))
+                if update_tags:
+                    self.tags = newtags
 
         if (self.to_do == Actions.Create) or (self.to_do == Actions.Update):
             self.log("Need to Create / Update the SQL Database instance")
@@ -388,6 +397,7 @@ class AzureRMDatabases(AzureRMModuleBase):
                 self.results['changed'] = True
                 return self.results
 
+            self.parameters['tags'] = self.tags
             response = self.create_update_sqldatabase()
 
             if not old_response:
@@ -432,7 +442,7 @@ class AzureRMDatabases(AzureRMModuleBase):
                                                                   server_name=self.server_name,
                                                                   database_name=self.name,
                                                                   parameters=self.parameters)
-            if isinstance(response, AzureOperationPoller):
+            if isinstance(response, LROPoller):
                 response = self.get_poller_result(response)
 
         except CloudError as exc:
@@ -479,6 +489,14 @@ class AzureRMDatabases(AzureRMModuleBase):
 
         return False
 
+    def format_elastic_pool_id(self):
+        parrent_id = format_resource_id(val=self.server_name,
+                                        subscription_id=self.subscription_id,
+                                        namespace="Microsoft.Sql",
+                                        types="servers",
+                                        resource_group=self.resource_group)
+        self.parameters['elastic_pool_id'] = parrent_id + "/elasticPools/" + self.parameters['elastic_pool_id']
+
 
 def _snake_to_camel(snake, capitalize_first=False):
     if capitalize_first:
@@ -489,7 +507,7 @@ def _snake_to_camel(snake, capitalize_first=False):
 
 def main():
     """Main execution"""
-    AzureRMDatabases()
+    AzureRMSqlDatabase()
 
 
 if __name__ == '__main__':
