@@ -18,6 +18,10 @@ author: "Ondra Machacek (@machacekondra)"
 description:
     - "Module to manage clusters in oVirt/RHV"
 options:
+    id:
+        description:
+            - "ID of the cluster to manage."
+        version_added: "2.8"
     name:
         description:
             - "Name of the cluster to manage."
@@ -44,43 +48,53 @@ options:
             - "If I(True) enable memory balloon optimization. Memory balloon is used to
                re-distribute / reclaim the host memory based on VM needs
                in a dynamic way."
+        type: bool
     virt:
         description:
             - "If I(True), hosts in this cluster will be used to run virtual machines."
+        type: bool
     gluster:
         description:
             - "If I(True), hosts in this cluster will be used as Gluster Storage
                server nodes, and not for running virtual machines."
             - "By default the cluster is created for virtual machine hosts."
+        type: bool
     threads_as_cores:
         description:
             - "If I(True) the exposed host threads would be treated as cores
                which can be utilized by virtual machines."
+        type: bool
     ksm:
         description:
             - "I I(True) MoM enables to run Kernel Same-page Merging I(KSM) when
                necessary and when it can yield a memory saving benefit that
                outweighs its CPU cost."
+        type: bool
     ksm_numa:
         description:
             - "If I(True) enables KSM C(ksm) for best performance inside NUMA nodes."
+        type: bool
     ha_reservation:
         description:
             - "If I(True) enables the oVirt/RHV to monitor cluster capacity for highly
                available virtual machines."
+        type: bool
     trusted_service:
         description:
             - "If I(True) enables integration with an OpenAttestation server."
+        type: bool
     vm_reason:
         description:
             - "If I(True) enables an optional reason field when a virtual machine
                is shut down from the Manager, allowing the administrator to
                provide an explanation for the maintenance."
+        type: bool
     host_reason:
         description:
             - "If I(True) enables an optional reason field when a host is placed
                into maintenance mode from the Manager, allowing the administrator
                to provide an explanation for the maintenance."
+        type: bool
     memory_policy:
         description:
             - "I(disabled) - Disables memory page sharing."
@@ -99,16 +113,32 @@ options:
         description:
             - "If I(True) enables fencing on the cluster."
             - "Fencing is enabled by default."
+        type: bool
+    fence_skip_if_gluster_bricks_up:
+        description:
+            - "A flag indicating if fencing should be skipped if Gluster bricks are up and running in the host being fenced."
+            - "This flag is optional, and the default value is `false`."
+        type: bool
+        version_added: "2.8"
+    fence_skip_if_gluster_quorum_not_met:
+        description:
+            - "A flag indicating if fencing should be skipped if Gluster bricks are up and running and Gluster quorum will not
+               be met without those bricks."
+            - "This flag is optional, and the default value is `false`."
+        type: bool
+        version_added: "2.8"
     fence_skip_if_sd_active:
         description:
             - "If I(True) any hosts in the cluster that are Non Responsive
                and still connected to storage will not be fenced."
+        type: bool
     fence_skip_if_connectivity_broken:
         description:
             - "If I(True) fencing will be temporarily disabled if the percentage
                of hosts in the cluster that are experiencing connectivity issues
                is greater than or equal to the defined threshold."
             - "The threshold can be specified by C(fence_connectivity_threshold)."
+        type: bool
     fence_connectivity_threshold:
         description:
             - "The threshold used by C(fence_skip_if_connectivity_broken)."
@@ -211,13 +241,30 @@ options:
                in the cluster. If the automatic deployment of the external
                network provider is supported, the networks of the referenced
                network provider are available on every host in the cluster."
-            - "External network provider is described by following dictionary:"
-            - "C(name) - Name of the external network provider. Either C(name)
-               or C(id) is required."
-            - "C(id) - ID of the external network provider. Either C(name) or
-               C(id) is required."
             - "This is supported since oVirt version 4.2."
+        suboptions:
+            name:
+                description:
+                    - Name of the external network provider. Either C(name) or C(id) is required.
+            id:
+                description:
+                    - ID of the external network provider. Either C(name) or C(id) is required.
         version_added: 2.5
+    firewall_type:
+        description:
+            - "The type of firewall to be used on hosts in this cluster."
+            - "Up to version 4.1, it was always I(iptables). Since version 4.2, you can choose between I(iptables) and I(firewalld).
+               For clusters with a compatibility version of 4.2 and higher, the default firewall type is I(firewalld)."
+        type: str
+        version_added: 2.8
+        choices: ['firewalld', 'iptables']
+    gluster_tuned_profile:
+        description:
+            - "The name of the U(https://fedorahosted.org/tuned) to set on all the hosts in the cluster. This is not mandatory
+               and relevant only for clusters with Gluster service."
+            - "Could be for example I(virtual-host), I(rhgs-sequential-io), I(rhgs-random-io)"
+        version_added: 2.8
+        type: str
 extends_documentation_fragment: ovirt
 '''
 
@@ -266,6 +313,11 @@ EXAMPLES = '''
 - ovirt_cluster:
     state: absent
     name: mycluster
+
+# Change cluster Name
+- ovirt_cluster:
+    id: 00000000-0000-0000-0000-000000000000
+    name: "new_cluster_name"
 '''
 
 RETURN = '''
@@ -381,6 +433,7 @@ class ClustersModule(BaseModule):
     def build_entity(self):
         sched_policy = self._get_sched_policy()
         return otypes.Cluster(
+            id=self.param('id'),
             name=self.param('name'),
             comment=self.param('comment'),
             description=self.param('description'),
@@ -435,6 +488,8 @@ class ClustersModule(BaseModule):
             ) if self.param('resilience_policy') else None,
             fencing_policy=otypes.FencingPolicy(
                 enabled=self.param('fence_enabled'),
+                skip_if_gluster_bricks_up=self.param('fence_skip_if_gluster_bricks_up'),
+                skip_if_gluster_quorum_not_met=self.param('fence_skip_if_gluster_quorum_not_met'),
                 skip_if_connectivity_broken=otypes.SkipIfConnectivityBroken(
                     enabled=self.param('fence_skip_if_connectivity_broken'),
                     threshold=self.param('fence_connectivity_threshold'),
@@ -449,6 +504,8 @@ class ClustersModule(BaseModule):
                 self.param('fence_enabled') is not None or
                 self.param('fence_skip_if_sd_active') is not None or
                 self.param('fence_skip_if_connectivity_broken') is not None or
+                self.param('fence_skip_if_gluster_bricks_up') is not None or
+                self.param('fence_skip_if_gluster_quorum_not_met') is not None or
                 self.param('fence_connectivity_threshold') is not None
             ) else None,
             display=otypes.Display(
@@ -500,6 +557,10 @@ class ClustersModule(BaseModule):
                     value=str(sp.get('value')),
                 ) for sp in self.param('scheduling_policy_properties') if sp
             ] if self.param('scheduling_policy_properties') is not None else None,
+            firewall_type=otypes.FirewallType(
+                self.param('firewall_type')
+            ) if self.param('firewall_type') else None,
+            gluster_tuned_profile=self.param('gluster_tuned_profile'),
         )
 
     def _matches_entity(self, item, entity):
@@ -543,6 +604,7 @@ class ClustersModule(BaseModule):
 
         return (
             check_custom_scheduling_policy_properties() and
+            equal(self.param('name'), entity.name) and
             equal(self.param('comment'), entity.comment) and
             equal(self.param('description'), entity.description) and
             equal(self.param('switch_type'), str(entity.switch_type)) and
@@ -560,6 +622,8 @@ class ClustersModule(BaseModule):
             equal(self.param('vm_reason'), entity.optional_reason) and
             equal(self.param('spice_proxy'), getattr(entity.display, 'proxy', None)) and
             equal(self.param('fence_enabled'), entity.fencing_policy.enabled) and
+            equal(self.param('fence_skip_if_gluster_bricks_up'), entity.fencing_policy.skip_if_gluster_bricks_up) and
+            equal(self.param('fence_skip_if_gluster_quorum_not_met'), entity.fencing_policy.skip_if_gluster_quorum_not_met) and
             equal(self.param('fence_skip_if_sd_active'), entity.fencing_policy.skip_if_sd_active.enabled) and
             equal(self.param('fence_skip_if_connectivity_broken'), entity.fencing_policy.skip_if_connectivity_broken.enabled) and
             equal(self.param('fence_connectivity_threshold'), entity.fencing_policy.skip_if_connectivity_broken.threshold) and
@@ -570,6 +634,8 @@ class ClustersModule(BaseModule):
             equal(self.param('serial_policy'), str(getattr(entity.serial_number, 'policy', None))) and
             equal(self.param('serial_policy_value'), getattr(entity.serial_number, 'value', None)) and
             equal(self.param('scheduling_policy'), getattr(self._connection.follow_link(entity.scheduling_policy), 'name', None)) and
+            equal(self.param('firewall_type'), str(entity.firewall_type)) and
+            equal(self.param('gluster_tuned_profile'), getattr(entity, 'gluster_tuned_profile', None)) and
             equal(self._get_policy_id(), getattr(migration_policy, 'id', None)) and
             equal(self._get_memory_policy(), entity.memory_policy.over_commit.percent) and
             equal(self.__get_minor(self.param('compatibility_version')), self.__get_minor(entity.version)) and
@@ -599,6 +665,7 @@ def main():
             default='present',
         ),
         name=dict(default=None, required=True),
+        id=dict(default=None),
         ballooning=dict(default=None, type='bool', aliases=['balloon']),
         gluster=dict(default=None, type='bool'),
         virt=dict(default=None, type='bool'),
@@ -613,6 +680,8 @@ def main():
         rng_sources=dict(default=None, type='list'),
         spice_proxy=dict(default=None),
         fence_enabled=dict(default=None, type='bool'),
+        fence_skip_if_gluster_bricks_up=dict(default=None, type='bool'),
+        fence_skip_if_gluster_quorum_not_met=dict(default=None, type='bool'),
         fence_skip_if_sd_active=dict(default=None, type='bool'),
         fence_skip_if_connectivity_broken=dict(default=None, type='bool'),
         fence_connectivity_threshold=dict(default=None, type='int'),
@@ -639,15 +708,14 @@ def main():
         mac_pool=dict(default=None),
         external_network_providers=dict(default=None, type='list'),
         scheduling_policy_properties=dict(type='list'),
+        firewall_type=dict(choices=['iptables', 'firewalld'], default=None),
+        gluster_tuned_profile=dict(default=None),
     )
     module = AnsibleModule(
         argument_spec=argument_spec,
         supports_check_mode=True,
     )
 
-    if module._name == 'ovirt_clusters':
-        module.deprecate("The 'ovirt_clusters' module is being renamed 'ovirt_cluster'", version=2.8)
-
     check_sdk(module)
 
     try:
