@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # -*- coding: UTF-8 -*-
 
-# Copyright (c) 2016, Adfinis SyGroup AG
+# Copyright: (c) 2016, Adfinis SyGroup AG
 # Tobias Rueetschi <tobias.ruetschi@adfinis-sygroup.ch>
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
@@ -18,7 +18,8 @@ DOCUMENTATION = '''
 ---
 module: udm_user
 version_added: "2.2"
-author: "Tobias Rueetschi (@2-B)"
+author:
+- Tobias Rüetschi (@keachi)
 short_description: Manage posix users on a univention corporate server
 description:
     - "This module allows to manage posix users on a univention corporate
@@ -125,6 +126,7 @@ options:
     organisation:
         description:
             - Organisation
+        aliases: [ organization ]
     override_pw_history:
         type: bool
         default: 'no'
@@ -330,7 +332,8 @@ def main():
                                          type='list',
                                          aliases=['mobileTelephoneNumber']),
             organisation=dict(default=None,
-                              type='str'),
+                              type='str',
+                              aliases=['organization']),
             overridePWHistory=dict(default=False,
                                    type='bool',
                                    aliases=['override_pw_history']),
@@ -410,20 +413,21 @@ def main():
     subpath = module.params['subpath']
     state = module.params['state']
     changed = False
+    diff = None
 
     users = list(ldap_search(
-        '(&(objectClass=posixAccount)(uid={}))'.format(username),
+        '(&(objectClass=posixAccount)(uid={0}))'.format(username),
         attr=['uid']
     ))
     if position != '':
         container = position
     else:
         if ou != '':
-            ou = 'ou={},'.format(ou)
+            ou = 'ou={0},'.format(ou)
         if subpath != '':
-            subpath = '{},'.format(subpath)
-        container = '{}{}{}'.format(subpath, ou, base_dn())
-    user_dn = 'uid={},{}'.format(username, container)
+            subpath = '{0},'.format(subpath)
+        container = '{0}{1}{2}'.format(subpath, ou, base_dn())
+    user_dn = 'uid={0},{1}'.format(username, container)
 
     exists = bool(len(users))
 
@@ -435,12 +439,12 @@ def main():
                 obj = umc_module_for_edit('users/user', user_dn)
 
             if module.params['displayName'] is None:
-                module.params['displayName'] = '{} {}'.format(
+                module.params['displayName'] = '{0} {1}'.format(
                     module.params['firstname'],
                     module.params['lastname']
                 )
             if module.params['unixhome'] is None:
-                module.params['unixhome'] = '/home/{}'.format(
+                module.params['unixhome'] = '/home/{0}'.format(
                     module.params['username']
                 )
             for k in obj.keys():
@@ -474,9 +478,9 @@ def main():
                     obj.create()
                 elif changed:
                     obj.modify()
-        except:
+        except Exception:
             module.fail_json(
-                msg="Creating/editing user {} in {} failed".format(
+                msg="Creating/editing user {0} in {1} failed".format(
                     username,
                     container
                 )
@@ -484,7 +488,7 @@ def main():
         try:
             groups = module.params['groups']
             if groups:
-                filter = '(&(objectClass=posixGroup)(|(cn={})))'.format(
+                filter = '(&(objectClass=posixGroup)(|(cn={0})))'.format(
                     ')(cn='.join(groups)
                 )
                 group_dns = list(ldap_search(filter, attr=['dn']))
@@ -495,9 +499,9 @@ def main():
                         if not module.check_mode:
                             grp.modify()
                         changed = True
-        except:
+        except Exception:
             module.fail_json(
-                msg="Adding groups to user {} failed".format(username)
+                msg="Adding groups to user {0} failed".format(username)
             )
 
     if state == 'absent' and exists:
@@ -506,9 +510,9 @@ def main():
             if not module.check_mode:
                 obj.remove()
             changed = True
-        except:
+        except Exception:
             module.fail_json(
-                msg="Removing user {} failed".format(username)
+                msg="Removing user {0} failed".format(username)
             )
 
     module.exit_json(
