@@ -21,6 +21,8 @@ short_description: Run PostgreSQL queries
 description:
 - Runs arbitrary PostgreSQL queries.
 - Can run queries from SQL script files.
+- Does not run against backup files. Use M(postgresql_db) with I(state=restore)
+  to run queries on files made by pg_dump/pg_dumpall utilities.
 version_added: '2.8'
 options:
   query:
@@ -66,6 +68,8 @@ options:
     type: bool
     default: no
     version_added: '2.9'
+seealso:
+- module: postgresql_db
 author:
 - Felix Archambault (@archf)
 - Andrew Klychkov (@Andersson007)
