@@ -29,7 +29,7 @@ options:
         aliases: [nic]
     protocol:
         description:
-            - Specifies the procotol for which we want to manage properties.
+            - Specifies the protocol for which we want to manage properties.
         required: true
     property:
         description:
@@ -46,6 +46,7 @@ options:
               property values do not persist across reboots.
         required: false
         default: false
+        type: bool
     state:
         description:
             - Set or reset the property value.
@@ -87,7 +88,7 @@ interface:
 state:
     description: state of the target
     returned: always
-    type: string
+    type: str
     sample: present
 value:
     description: property's value
