@@ -24,13 +24,16 @@ options:
     description:
       - The name of a Python library to install or the url(bzr+,hg+,git+,svn+) of the remote package.
       - This can be a list (since 2.2) and contain version specifiers (since 2.7).
+    type: list
   version:
     description:
       - The version number to install of the Python library specified in the I(name) parameter.
+    type: str
   requirements:
     description:
       - The path to a pip requirements file, which should be local to the remote system.
         File can be specified as a relative path if using the chdir option.
+    type: str
   virtualenv:
     description:
       - An optional path to a I(virtualenv) directory to install into.
@@ -39,6 +42,7 @@ options:
         If the virtualenv does not exist, it will be created before installing
         packages. The optional virtualenv_site_packages, virtualenv_command,
         and virtualenv_python options affect the creation of the virtualenv.
+    type: path
   virtualenv_site_packages:
     description:
       - Whether the virtual environment will inherit packages from the
@@ -54,6 +58,7 @@ options:
       - The command or a pathname to the command to create the virtual
         environment with. For example C(pyvenv), C(virtualenv),
         C(virtualenv2), C(~/bin/virtualenv), C(/usr/local/bin/virtualenv).
+    type: path
     default: virtualenv
     version_added: "1.1"
   virtualenv_python:
@@ -63,16 +68,19 @@ options:
         Python version used to run the ansible module is used. This parameter
         should not be used when C(virtualenv_command) is using C(pyvenv) or
         the C(-m venv) module.
+    type: str
     version_added: "2.0"
   state:
     description:
       - The state of module
       - The 'forcereinstall' option is only available in Ansible 2.1 and above.
+    type: str
     choices: [ absent, forcereinstall, latest, present ]
     default: present
   extra_args:
     description:
       - Extra arguments passed to pip.
+    type: str
     version_added: "1.0"
   editable:
     description:
@@ -83,16 +91,19 @@ options:
   chdir:
     description:
       - cd into this directory before running the command
+    type: path
     version_added: "1.3"
   executable:
     description:
-      - The explicit executable or a pathname to the executable to be used to
-        run pip for a specific version of Python installed in the system. For
-        example C(pip-3.3), if there are both Python 2.7 and 3.3 installations
+      - The explicit executable or pathname for the pip executable,
+        if different from the Ansible Python interpreter. For
+        example C(pip3.3), if there are both Python 2.7 and 3.3 installations
         in the system and you want to run pip for the Python 3.3 installation.
-        It cannot be specified together with the 'virtualenv' parameter (added in 2.1).
-        By default, it will take the appropriate version for the python interpreter
-        use by ansible, e.g. pip3 on python 3, and pip2 or pip on python 2.
+      - Mutually exclusive with I(virtualenv) (added in 2.1).
+      - Does not affect the Ansible Python interpreter.
+      - The setuptools package must be installed for both the Ansible Python interpreter
+        and for the version of Python specified by this option.
+    type: path
     version_added: "1.3"
   umask:
     description:
@@ -101,13 +112,19 @@ options:
         restrictive umask by default (e.g., "0077") and you want to pip install
         packages which are to be used by all users. Note that this requires you
         to specify desired umask mode as an octal string, (e.g., "0022").
+    type: str
     version_added: "2.1"
 notes:
-   - Please note that virtualenv (U(http://www.virtualenv.org/)) must be
+   - The virtualenv (U(http://www.virtualenv.org/)) must be
      installed on the remote host if the virtualenv parameter is specified and
      the virtualenv needs to be created.
-   - By default, this module will use the appropriate version of pip for the
-     interpreter used by ansible (e.g. pip3 when using python 3, pip2 otherwise)
+   - Although it executes using the Ansible Python interpreter, the pip module shells out to
+     run the actual pip command, so it can use any pip version you specify with I(executable).
+     By default, it uses the pip version for the Ansible Python interpreter. For example, pip3 on python 3, and pip2 or pip on python 2.
+   - The interpreter used by Ansible
+     (see :ref:`ansible_python_interpreter<ansible_python_interpreter>`)
+     requires the setuptools package, regardless of the version of pip set with
+     the I(executable) option.
 requirements:
 - pip
 - virtualenv
@@ -195,10 +212,10 @@ EXAMPLES = '''
     requirements: /my_app/requirements.txt
     extra_args: "--no-index --find-links=file:///my_downloaded_packages_dir"
 
-# Install (Bottle) for Python 3.3 specifically,using the 'pip-3.3' executable.
+# Install (Bottle) for Python 3.3 specifically,using the 'pip3.3' executable.
 - pip:
     name: bottle
-    executable: pip-3.3
+    executable: pip3.3
 
 # Install (Bottle), forcing reinstallation if it's already installed
 - pip:
@@ -569,14 +586,13 @@ def main():
     module = AnsibleModule(
         argument_spec=dict(
             state=dict(type='str', default='present', choices=state_map.keys()),
-            name=dict(type='list'),
+            name=dict(type='list', elements='str'),
             version=dict(type='str'),
             requirements=dict(type='str'),
             virtualenv=dict(type='path'),
             virtualenv_site_packages=dict(type='bool', default=False),
             virtualenv_command=dict(type='path', default='virtualenv'),
             virtualenv_python=dict(type='str'),
-            use_mirrors=dict(type='bool', default=True),
             extra_args=dict(type='str'),
             editable=dict(type='bool', default=False),
             chdir=dict(type='path'),
