@@ -14,7 +14,7 @@ ANSIBLE_METADATA = {'metadata_version': '1.1',
 DOCUMENTATION = r'''
 module: win_hostname
 version_added: "2.6"
-short_description: Manages local Windows computer name.
+short_description: Manages local Windows computer name
 description:
 - Manages local Windows computer name.
 - A reboot is required for the computer name to take effect.
@@ -22,7 +22,10 @@ options:
   name:
     description:
     - The hostname to set for the computer.
+    type: str
     required: true
+seealso:
+- module: win_dns_client
 author:
 - Ripon Banik (@riponbanik)
 '''
@@ -40,12 +43,12 @@ EXAMPLES = r'''
 
 RETURN = r'''
 old_name:
-  description: The original hostname that was set before it was changed
+  description: The original hostname that was set before it was changed.
   returned: always
   type: str
   sample: old_hostname
 reboot_required:
-  description: Whether a reboot is required to complete the hostname change
+  description: Whether a reboot is required to complete the hostname change.
   returned: always
   type: bool
   sample: true
