@@ -19,35 +19,35 @@
 from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
-import sys
 import copy
+import re
+import sys
 
 from ansible import constants as C
 from ansible.module_utils._text import to_text
 from ansible.module_utils.connection import Connection
-from ansible.plugins.action.normal import ActionModule as _ActionModule
+from ansible.plugins.action.network import ActionModule as ActionNetworkModule
 from ansible.module_utils.network.common.utils import load_provider
 from ansible.module_utils.network.nxos.nxos import nxos_provider_spec
+from ansible.utils.display import Display
 
-try:
-    from __main__ import display
-except ImportError:
-    from ansible.utils.display import Display
-    display = Display()
+display = Display()
 
 
-class ActionModule(_ActionModule):
+class ActionModule(ActionNetworkModule):
 
     def run(self, tmp=None, task_vars=None):
         del tmp  # tmp no longer has any effect
 
+        module_name = self._task.action.split('.')[-1]
+        self._config_module = True if module_name == 'nxos_config' else False
         socket_path = None
 
         if (self._play_context.connection == 'httpapi' or self._task.args.get('provider', {}).get('transport') == 'nxapi') \
-                and self._task.action in ('nxos_file_copy', 'nxos_nxapi'):
-            return {'failed': True, 'msg': "Transport type 'nxapi' is not valid for '%s' module." % (self._task.action)}
+                and module_name in ('nxos_file_copy', 'nxos_nxapi'):
+            return {'failed': True, 'msg': "Transport type 'nxapi' is not valid for '%s' module." % (module_name)}
 
-        if self._task.action == 'nxos_file_copy':
+        if module_name == 'nxos_file_copy':
             self._task.args['host'] = self._play_context.remote_addr
             self._task.args['password'] = self._play_context.password
             if self._play_context.connection == 'network_cli':
@@ -55,10 +55,24 @@ class ActionModule(_ActionModule):
             elif self._play_context.connection == 'local':
                 self._task.args['username'] = self._play_context.connection_user
 
-        if self._task.action == 'nxos_install_os':
-            if C.PERSISTENT_COMMAND_TIMEOUT < 600 or C.PERSISTENT_CONNECT_TIMEOUT < 600:
+        if module_name == 'nxos_install_os':
+            persistent_command_timeout = 0
+            persistent_connect_timeout = 0
+            connection = self._connection
+            if connection.transport == 'local':
+                persistent_command_timeout = C.PERSISTENT_COMMAND_TIMEOUT
+                persistent_connect_timeout = C.PERSISTENT_CONNECT_TIMEOUT
+            else:
+                persistent_command_timeout = connection.get_option('persistent_command_timeout')
+                persistent_connect_timeout = connection.get_option('persistent_connect_timeout')
+
+            display.vvvv('PERSISTENT_COMMAND_TIMEOUT is %s' % str(persistent_command_timeout), self._play_context.remote_addr)
+            display.vvvv('PERSISTENT_CONNECT_TIMEOUT is %s' % str(persistent_connect_timeout), self._play_context.remote_addr)
+            if persistent_command_timeout < 600 or persistent_connect_timeout < 600:
                 msg = 'PERSISTENT_COMMAND_TIMEOUT and PERSISTENT_CONNECT_TIMEOUT'
-                msg += ' must be set to 600 seconds or higher when using nxos_install_os module'
+                msg += ' must be set to 600 seconds or higher when using nxos_install_os module.'
+                msg += ' Current persistent_command_timeout setting:' + str(persistent_command_timeout)
+                msg += ' Current persistent_connect_timeout setting:' + str(persistent_connect_timeout)
                 return {'failed': True, 'msg': msg}
 
         if self._play_context.connection in ('network_cli', 'httpapi'):
@@ -117,8 +131,10 @@ class ActionModule(_ActionModule):
                 socket_path = self._connection.socket_path
 
             conn = Connection(socket_path)
+            # Match prompts ending in )# except those with (maint-mode)#
+            config_prompt = re.compile(r'^.*\((?!maint-mode).*\)#$')
             out = conn.get_prompt()
-            while to_text(out, errors='surrogate_then_replace').strip().endswith(')#'):
+            while config_prompt.match(to_text(out, errors='surrogate_then_replace').strip()):
                 display.vvvv('wrong context, sending exit to device', self._play_context.remote_addr)
                 conn.send_command('exit')
                 out = conn.get_prompt()
