@@ -22,10 +22,9 @@ __metaclass__ = type
 import json
 import re
 
-from ansible.module_utils._text import to_text, to_bytes, to_native
+from ansible.module_utils._text import to_text, to_bytes
 from ansible.errors import AnsibleConnectionFailure
-from ansible.plugins.netconf import NetconfBase
-from ansible.plugins.netconf import ensure_connected, ensure_ncclient
+from ansible.plugins.netconf import NetconfBase, ensure_ncclient
 
 try:
     from ncclient import manager
@@ -55,25 +54,35 @@ class Netconf(NetconfBase):
     def get_device_info(self):
         device_info = dict()
         device_info['network_os'] = 'ce'
-        ele = new_ele('get-software-information')
-        data = self.execute_rpc(to_xml(ele))
-        reply = to_ele(to_bytes(data, errors='surrogate_or_strict'))
-        sw_info = reply.find('.//software-information')
+        filter_xml = '''<filter type="subtree">
+                          <system xmlns="http://www.huawei.com/netconf/vrp" content-version="1.0" format-version="1.0">
+                            <systemInfo>
+                              <sysName></sysName>
+                              <sysContact></sysContact>
+                              <productVer></productVer>
+                              <platformVer></platformVer>
+                              <productName></productName>
+                            </systemInfo>
+                          </system>
+                        </filter>'''
+        data = self.get(filter_xml)
+        data = re.sub(r'xmlns=".+?"', r'', data)
+        reply = fromstring(to_bytes(data, errors='surrogate_or_strict'))
+        sw_info = reply.find('.//systemInfo')
 
-        device_info['network_os_version'] = self.get_text(sw_info, 'ce-version')
-        device_info['network_os_hostname'] = self.get_text(sw_info, 'host-name')
-        device_info['network_os_model'] = self.get_text(sw_info, 'product-model')
+        device_info['network_os_version'] = self.get_text(sw_info, 'productVer')
+        device_info['network_os_hostname'] = self.get_text(sw_info, 'sysName')
+        device_info['network_os_platform_version'] = self.get_text(sw_info, 'platformVer')
+        device_info['network_os_platform'] = self.get_text(sw_info, 'productName')
 
         return device_info
 
-    @ensure_connected
     def execute_rpc(self, name):
         """RPC to be execute on remote device
            :name: Name of rpc in string format"""
         return self.rpc(name)
 
     @ensure_ncclient
-    @ensure_connected
     def load_configuration(self, *args, **kwargs):
         """Loads given configuration on device
         :format: Format of configuration (xml, text, set)
@@ -121,7 +130,7 @@ class Netconf(NetconfBase):
                 ssh_config=obj._ssh_config
             )
         except SSHUnknownHostError as exc:
-            raise AnsibleConnectionFailure(to_native(exc))
+            raise AnsibleConnectionFailure(to_text(exc))
 
         guessed_os = None
         for c in m.server_capabilities:
@@ -132,7 +141,6 @@ class Netconf(NetconfBase):
         m.close_session()
         return guessed_os
 
-    @ensure_connected
     def get_configuration(self, *args, **kwargs):
         """Retrieve all or part of a specified configuration.
            :format: format in configuration should be retrieved
@@ -140,14 +148,12 @@ class Netconf(NetconfBase):
            (by default entire configuration is retrieved)"""
         return self.m.get_configuration(*args, **kwargs).data_xml
 
-    @ensure_connected
     def compare_configuration(self, *args, **kwargs):
         """Compare configuration
            :rollback: rollback id"""
         return self.m.compare_configuration(*args, **kwargs).data_xml
 
     @ensure_ncclient
-    @ensure_connected
     def execute_action(self, xml_str):
         """huawei execute-action"""
         con_obj = None
@@ -158,18 +164,15 @@ class Netconf(NetconfBase):
 
         return con_obj.xml
 
-    @ensure_connected
     def halt(self):
         """reboot the device"""
         return self.m.halt().data_xml
 
-    @ensure_connected
     def reboot(self):
         """reboot the device"""
         return self.m.reboot().data_xml
 
     @ensure_ncclient
-    @ensure_connected
     def get(self, *args, **kwargs):
         try:
             if_rpc_reply = kwargs.pop('if_rpc_reply', False)
@@ -180,7 +183,6 @@ class Netconf(NetconfBase):
             raise Exception(to_xml(exc.xml))
 
     @ensure_ncclient
-    @ensure_connected
     def get_config(self, *args, **kwargs):
         try:
             return self.m.get_config(*args, **kwargs).data_xml
@@ -188,7 +190,6 @@ class Netconf(NetconfBase):
             raise Exception(to_xml(exc.xml))
 
     @ensure_ncclient
-    @ensure_connected
     def edit_config(self, *args, **kwargs):
         try:
             return self.m.edit_config(*args, **kwargs).xml
@@ -196,7 +197,6 @@ class Netconf(NetconfBase):
             raise Exception(to_xml(exc.xml))
 
     @ensure_ncclient
-    @ensure_connected
     def execute_nc_cli(self, *args, **kwargs):
         try:
             return self.m.cli(*args, **kwargs).xml
@@ -204,23 +204,19 @@ class Netconf(NetconfBase):
             raise Exception(to_xml(exc.xml))
 
     @ensure_ncclient
-    @ensure_connected
     def commit(self, *args, **kwargs):
         try:
             return self.m.commit(*args, **kwargs).data_xml
         except RPCError as exc:
             raise Exception(to_xml(exc.xml))
 
-    @ensure_connected
     def validate(self, *args, **kwargs):
         return self.m.validate(*args, **kwargs).data_xml
 
-    @ensure_connected
     def discard_changes(self, *args, **kwargs):
         return self.m.discard_changes(*args, **kwargs).data_xml
 
     @ensure_ncclient
-    @ensure_connected
     def dispatch_rpc(self, rpc_command=None, source=None, filter=None):
         """
         Execute rpc on the remote device eg. dispatch('get-next')
